@@ -1,6 +1,6 @@
 /*
-* libtcod 1.6.1
-* Copyright (c) 2008,2009,2010,2012,2013 Jice & Mingos & rmtew
+* libtcod 1.6.3
+* Copyright (c) 2008,2009,2010,2012,2013,2016,2017 Jice & Mingos & rmtew
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
@@ -13,10 +13,10 @@
 *     * The name of Jice or Mingos may not be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
-* THIS SOFTWARE IS PROVIDED BY JICE AND MINGOS ``AS IS'' AND ANY
+* THIS SOFTWARE IS PROVIDED BY JICE, MINGOS AND RMTEW ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-* DISCLAIMED. IN NO EVENT SHALL JICE OR MINGOS BE LIABLE FOR ANY
+* DISCLAIMED. IN NO EVENT SHALL JICE, MINGOS OR RMTEW BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
@@ -35,13 +35,15 @@
 
 typedef void * TCOD_console_t;
 
+#include "image.h"
+
 TCODLIB_API void TCOD_console_init_root(int w, int h, const char * title, bool fullscreen, TCOD_renderer_t renderer);
 TCODLIB_API void TCOD_console_set_window_title(const char *title);
 TCODLIB_API void TCOD_console_set_fullscreen(bool fullscreen);
-TCODLIB_API bool TCOD_console_is_fullscreen();
-TCODLIB_API bool TCOD_console_is_window_closed();
-TCODLIB_API bool TCOD_console_has_mouse_focus();
-TCODLIB_API bool TCOD_console_is_active();
+TCODLIB_API bool TCOD_console_is_fullscreen(void);
+TCODLIB_API bool TCOD_console_is_window_closed(void);
+TCODLIB_API bool TCOD_console_has_mouse_focus(void);
+TCODLIB_API bool TCOD_console_is_active(void);
 
 TCODLIB_API void TCOD_console_set_custom_font(const char *fontFile, int flags,int nb_char_horiz, int nb_char_vertic);
 TCODLIB_API void TCOD_console_map_ascii_code_to_font(int asciiCode, int fontCharX, int fontCharY);
@@ -90,18 +92,19 @@ TCODLIB_API TCOD_color_t TCOD_console_get_char_background(TCOD_console_t con,int
 TCODLIB_API TCOD_color_t TCOD_console_get_char_foreground(TCOD_console_t con,int x, int y);
 TCODLIB_API int TCOD_console_get_char(TCOD_console_t con,int x, int y);
 
-TCODLIB_API void TCOD_console_set_fade(uint8 val, TCOD_color_t fade);
-TCODLIB_API uint8 TCOD_console_get_fade();
-TCODLIB_API TCOD_color_t TCOD_console_get_fading_color();
+TCODLIB_API TCOD_image_t TCOD_console_get_background_color_image(TCOD_console_t con);
+TCODLIB_API TCOD_image_t TCOD_console_get_foreground_color_image(TCOD_console_t con);
 
-TCODLIB_API void TCOD_console_flush();
+TCODLIB_API void TCOD_console_set_fade(uint8 val, TCOD_color_t fade);
+TCODLIB_API uint8 TCOD_console_get_fade(void);
+TCODLIB_API TCOD_color_t TCOD_console_get_fading_color(void);
+
+TCODLIB_API void TCOD_console_flush(void);
 
 TCODLIB_API void TCOD_console_set_color_control(TCOD_colctrl_t con, TCOD_color_t fore, TCOD_color_t back);
 
 TCODLIB_API TCOD_key_t TCOD_console_check_for_keypress(int flags);
 TCODLIB_API TCOD_key_t TCOD_console_wait_for_keypress(bool flush);
-TCODLIB_API void TCOD_console_set_keyboard_repeat(int initial_delay, int interval);
-TCODLIB_API void TCOD_console_disable_keyboard_repeat();
 TCODLIB_API bool TCOD_console_is_key_pressed(TCOD_keycode_t key);
 
 /* ASCII paint file support */
@@ -118,8 +121,8 @@ TCODLIB_API void TCOD_console_set_key_color(TCOD_console_t con,TCOD_color_t col)
 TCODLIB_API void TCOD_console_blit(TCOD_console_t src,int xSrc, int ySrc, int wSrc, int hSrc, TCOD_console_t dst, int xDst, int yDst, float foreground_alpha, float background_alpha);
 TCODLIB_API void TCOD_console_delete(TCOD_console_t console);
 
-TCODLIB_API void TCOD_console_credits();
-TCODLIB_API void TCOD_console_credits_reset();
+TCODLIB_API void TCOD_console_credits(void);
+TCODLIB_API void TCOD_console_credits_reset(void);
 TCODLIB_API bool TCOD_console_credits_render(int x, int y, bool alpha);
 
 #endif
