@@ -1,6 +1,6 @@
 /*
-* libtcod 1.6.0
-* Copyright (c) 2008,2009,2010,2012,2013 Jice & Mingos
+* libtcod 1.6.3
+* Copyright (c) 2008,2009,2010,2012,2013,2016,2017 Jice & Mingos & rmtew
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
@@ -13,10 +13,10 @@
 *     * The name of Jice or Mingos may not be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
-* THIS SOFTWARE IS PROVIDED BY JICE AND MINGOS ``AS IS'' AND ANY
+* THIS SOFTWARE IS PROVIDED BY JICE, MINGOS AND RMTEW ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-* DISCLAIMED. IN NO EVENT SHALL JICE OR MINGOS BE LIABLE FOR ANY
+* DISCLAIMED. IN NO EVENT SHALL JICE, MINGOS OR RMTEW BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
@@ -28,6 +28,9 @@
 #ifndef _TCOD_CONSOLE_HPP
 #define _TCOD_CONSOLE_HPP
 
+class TCODConsole;
+
+#include "image.hpp"
 #include "console_types.h"
 
 /**
@@ -994,6 +997,26 @@ public :
 	*/
 	void printFrame(int x,int y,int w,int h, bool clear=true, TCOD_bkgnd_flag_t flag = TCOD_BKGND_DEFAULT, const char *fmt=NULL, ...);
 
+	/**
+	@PageName console_advanced
+	@FuncTitle Manipulating foreground colors as an image
+	@FuncDesc This function obtains the image containing the console foreground colors.
+	@Cpp TCODImage *TCODConsole::getForegroundImage()
+	@C TCOD_image_t TCOD_console_get_foreground_color_image(TCOD_console_t con)
+	@Py console_get_foreground_image(con)
+	*/
+	TCODImage *getForegroundColorImage();
+
+	/**
+	@PageName console_advanced
+	@FuncTitle Manipulating background colors as an image
+	@FuncDesc This function obtains the image containing the console background colors.
+	@Cpp TCODImage *TCODConsole::getBackgroundImage()
+	@C TCOD_image_t TCOD_console_get_background_color_image(TCOD_console_t con)
+	@Py console_get_background_image(con)
+	*/
+	TCODImage *getBackgroundColorImage();
+
 	/**
 	@PageName console_read
 	@PageTitle Reading the content of the console
@@ -1314,30 +1337,6 @@ public :
 	@Param key Any key code defined in keycode_t except TCODK_CHAR (Char) and TCODK_NONE (NoKey)
 	*/
 	static bool isKeyPressed(TCOD_keycode_t key);
-	/**
-	@PageName console_keyboard_repeat
-	@PageTitle Changing keyboard repeat delay
-	@PageFather console_input
-	@FuncDesc This function changes the keyboard repeat times.
-	@Cpp static void TCODConsole::setKeyboardRepeat(int initialDelay, int interval)
-	@C void TCOD_console_set_keyboard_repeat(int initial_delay, int interval)
-	@Py console_set_keyboard_repeat(initial_delay, interval)
-	@C# static void TCODConsole::setKeyboardRepeat(int initialDelay, int interval)
-	@Lua tcod.console.setKeyboardRepeat(initialDelay, interval)
-	@Param initialDelay delay in millisecond between the time when a key is pressed, and keyboard repeat begins. If 0, keyboard repeat is disabled
-	@Param interval interval in millisecond between keyboard repeat events
-	*/
-	static void setKeyboardRepeat(int initialDelay,int interval);
-	/**
-	@PageName console_keyboard_repeat
-	@FuncDesc You can also disable the keyboard repeat feature with this function (it's equivalent to setKeyboardRepeat(0,0) ).
-	@Cpp static void TCODConsole::disableKeyboardRepeat()
-	@C void TCOD_console_disable_keyboard_repeat()
-	@Py console_disable_keyboard_repeat()
-	@C# static void TCODConsole::disableKeyboardRepeat()
-	@Lua tcod.console.disableKeyboardRepeat()
-	*/
-	static void disableKeyboardRepeat();
 
 	/**
 	@PageName console_key_t
