@@ -1,6 +1,6 @@
 /*
-* libtcod 1.6.1
-* Copyright (c) 2008,2009,2010 Jice & Mingos
+* libtcod 1.6.3
+* Copyright (c) 2008,2009,2010,2016,2017 Jice & Mingos & rmtew
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
@@ -13,10 +13,10 @@
 *     * The name of Jice or Mingos may not be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
-* THIS SOFTWARE IS PROVIDED BY JICE AND MINGOS ``AS IS'' AND ANY
+* THIS SOFTWARE IS PROVIDED BY JICE, MINGOS AND RMTEW ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-* DISCLAIMED. IN NO EVENT SHALL JICE OR MINGOS BE LIABLE FOR ANY
+* DISCLAIMED. IN NO EVENT SHALL JICE, MINGOS OR RMTEW BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
@@ -33,6 +33,10 @@
 #include <sys/stat.h>
 #include "libtcod.hpp"
 
+#ifdef TCOD_WINDOWS
+#define strdup _strdup
+#endif
+
 // index.html categories
 static const char *categs[] = {"", "Core","Base toolkits","Roguelike toolkits", "Howtos", NULL };
 
@@ -360,6 +364,7 @@ void printCCode(FILE *f, const char *txt) {
 	static const char *symbols[] = {
 		"->","++","--","<<",">>","<=",">=","==","!=","&&","||","*=","/=","+=","-=","%=","<<=",">>=","&=","^=","|=","...",
 		"{","}","(",")","[","]",".","&","*","+","-","~","!","/","%","<",">","^","|","?",":","=",",",";",
+		NULL
 	};
 	static const char *keywords[] = {
 	"auto","break","case","char","const","continue","default","do","double","else","enum","extern","float","for","goto","if","int",
@@ -543,15 +548,15 @@ void parseFile(char *filename) {
 					directive += sizeof("@ColorTable");
 					curPage->colorTable=true;
 	    		} else if ( startsWith(directive,"@ColorCategory") ) {
-					Color col;
-					directive=getLineEnd(directive+sizeof("@ColorCategory"),&col.name);
-					col.category=true;
-					colors.push(col);
+					Color *catCol = new Color();
+					directive=getLineEnd(directive+sizeof("@ColorCategory"),&catCol->name);
+					catCol->category=true;
+					colors.push(*catCol);
 	    		} else if ( startsWith(directive,"@Color") ) {
-					Color col;
-					directive=getIdentifier(directive+sizeof("@Color"),&col.name);
-					sscanf(directive,"%d,%d,%d",&col.col.r,&col.col.g,&col.col.b);
-					colors.push(col);
+					Color *col = new Color();
+					directive=getIdentifier(directive+sizeof("@Color"),&col->name);
+					sscanf(directive,"%d,%d,%d",&col->col.r,&col->col.g,&col->col.b);
+					colors.push(*col);
 					while (! isspace(*directive)) directive++;
 	    		} else if ( startsWith(directive,"@FuncDesc") ) {
 					if (! curFunc ) {
