@@ -13,14 +13,7 @@
 #include <math.h>
 #include "libtcod.hpp"
 #define _SDL_main_h
-#if defined (__HAIKU__) || defined (__ANDROID__)
 #include <SDL.h>
-#elif defined (TCOD_SDL2)
-#include <SDL.h>
-#else
-#include <SDL/SDL.h>
-#endif
-
 
 // a sample has a name and a rendering function
 typedef struct {
