@@ -1,6 +1,6 @@
 /*
-* libtcod 1.6.1
-* Copyright (c) 2008,2009,2010,2012,2013 Jice & Mingos & rmtew
+* libtcod 1.6.3
+* Copyright (c) 2008,2009,2010,2012,2013,2016,2017 Jice & Mingos & rmtew
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
@@ -13,10 +13,10 @@
 *     * The name of Jice or Mingos may not be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
-* THIS SOFTWARE IS PROVIDED BY JICE AND MINGOS ``AS IS'' AND ANY
+* THIS SOFTWARE IS PROVIDED BY JICE, MINGOS AND RMTEW ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-* DISCLAIMED. IN NO EVENT SHALL JICE OR MINGOS BE LIABLE FOR ANY
+* DISCLAIMED. IN NO EVENT SHALL JICE, MINGOS OR RMTEW BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
@@ -45,6 +45,28 @@ typedef struct {
 	bool has_key_color;
 } image_data_t;
 
+/*
+Internal libtcod optimisation, direct colour manipulation in the images primary mipmap.
+*/
+TCOD_color_t *TCOD_image_get_colors(TCOD_image_t *image) {
+	image_data_t *img = ((image_data_t *)image);
+	return img->mipmaps[0].buf;
+}
+
+void TCOD_image_get_key_data(TCOD_image_t image, bool *has_key_color, TCOD_color_t *key_color) {
+	image_data_t *img = ((image_data_t *)image);
+	*has_key_color = img->has_key_color;
+	*key_color = img->key_color;
+}
+
+void TCOD_image_invalidate_mipmaps(TCOD_image_t *image) {
+	int i;
+	image_data_t *img = ((image_data_t *)image);
+	for (i = 1; i < img->nb_mipmaps; i++) {
+		img->mipmaps[i].dirty = true;
+	}
+}
+
 static int TCOD_image_get_mipmap_levels(int width, int height) {
 	int curw=width;
 	int curh=height;
@@ -90,6 +112,25 @@ static void TCOD_image_generate_mip(image_data_t *img, int mip) {
 	}
 }
 
+/*
+Internal way of copying rendering fg/bg color frame data.
+*/
+bool TCOD_image_mipmap_copy_internal(TCOD_image_t srcImage, TCOD_image_t dstImage) {
+	int i;
+	image_data_t *img_src = (image_data_t *)srcImage;
+	image_data_t *img_dst = (image_data_t *)dstImage;
+	if (!img_src->mipmaps || img_src->sys_img || !img_dst->mipmaps || img_dst->sys_img) /* Both internal images. */
+		return false;
+	if (img_src->mipmaps[0].width != img_dst->mipmaps[0].width || img_src->mipmaps[0].height != img_dst->mipmaps[0].height)
+		return false;
+	/* Copy all mipmaps? */
+	img_dst->mipmaps[0].dirty = img_src->mipmaps[0].dirty;
+	memcpy(img_dst->mipmaps[0].buf, img_src->mipmaps[0].buf, sizeof(TCOD_color_t)*(img_src->mipmaps[0].width)*(img_src->mipmaps[0].height));
+	for (i = 1; i < img_src->nb_mipmaps; i++)
+		img_dst->mipmaps[i].dirty = true;
+	return true;
+}
+
 static void TCOD_image_init_mipmaps(image_data_t *img) {
 	int w,h,i,x,y;
 	float fw,fh;
@@ -382,8 +423,14 @@ TCOD_image_t TCOD_image_from_console(TCOD_console_t console) {
 
 void TCOD_image_refresh_console(TCOD_image_t image, TCOD_console_t console) {
 	image_data_t *img=(image_data_t *)image;
+
+	/* We're copying the state and clearing part of the copy, no need to delete/free. */
+	TCOD_render_state_t partial_render_state = *TCOD_console_get_render_state(console);
+	partial_render_state.oldbuf = NULL;
+	partial_render_state.bg_colors_prev = NULL;
+	partial_render_state.fg_colors_prev = NULL;
 	TCOD_sys_console_to_bitmap(img->sys_img, TCOD_console_get_width(console), TCOD_console_get_height(console),
-		TCOD_console_get_buf(console),NULL);
+		&partial_render_state);
 }
 
 void TCOD_image_save(TCOD_image_t image, const char *filename) {
@@ -409,6 +456,7 @@ void TCOD_image_set_key_color(TCOD_image_t image, TCOD_color_t key_color) {
 	img->has_key_color=true;
 	img->key_color=key_color;
 }
+
 void TCOD_image_invert(TCOD_image_t image) {
 	int i,mip;
 	int width,height;
