@@ -1,6 +1,6 @@
 /*
-* libtcod 1.6.1
-* Copyright (c) 2008,2009,2010,2012,2013 Jice & Mingos & rmtew
+* libtcod 1.6.3
+* Copyright (c) 2008,2009,2010,2012,2013,2016,2017 Jice & Mingos & rmtew
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
@@ -13,10 +13,10 @@
 *     * The name of Jice or Mingos may not be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
-* THIS SOFTWARE IS PROVIDED BY JICE AND MINGOS ``AS IS'' AND ANY
+* THIS SOFTWARE IS PROVIDED BY JICE, MINGOS AND RMTEW ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-* DISCLAIMED. IN NO EVENT SHALL JICE OR MINGOS BE LIABLE FOR ANY
+* DISCLAIMED. IN NO EVENT SHALL JICE, MINGOS OR RMTEW BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
@@ -78,16 +78,12 @@ static image_support_t image_type[] = {
 };
 
 scale_data_t scale_data={0};
-#ifdef TCOD_SDL2
 SDL_Window* window=NULL;
 SDL_Renderer* renderer=NULL;
 float scale_factor=1.0f;
-#else
-SDL_Surface* screen=NULL;
-#endif
 SDL_Surface* charmap=NULL;
-static char_t *consoleBuffer=NULL;
-static char_t *prevConsoleBuffer=NULL;
+static TCOD_render_state_t *renderState = NULL;
+char *last_clipboard_text = NULL;
 static bool has_startup=false;
 #define MAX_SCALE_FACTOR 5.0f
 
@@ -123,16 +119,12 @@ static bool key_status[TCODK_CHAR+1];
 int oldFade=-1;
 
 /* convert SDL vk to a char (depends on the keyboard layout) */
-#ifdef TCOD_SDL2
 typedef struct {
 	SDL_Keycode	sdl_key;
 	int tcod_key;
 } vk_to_c_entry;
 #define NUM_VK_TO_C_ENTRIES 10
 static vk_to_c_entry vk_to_c[NUM_VK_TO_C_ENTRIES];
-#else
-static char vk_to_c[SDLK_LAST];
-#endif
 
 /* convert ASCII code to TCOD layout position */
 static int init_ascii_to_tcod[256] = {
@@ -157,7 +149,7 @@ static int init_ascii_to_tcod[256] = {
 bool *ascii_updated=NULL;
 bool any_ascii_updated=false;
 
-static void alloc_ascii_tables() {
+static void alloc_ascii_tables(void) {
 	if ( TCOD_ctx.ascii_to_tcod ) free(TCOD_ctx.ascii_to_tcod);
 	if ( ascii_updated ) free(ascii_updated);
 	if ( charcols ) {
@@ -172,7 +164,7 @@ static void alloc_ascii_tables() {
 	memcpy(TCOD_ctx.ascii_to_tcod,init_ascii_to_tcod,sizeof(int)*256);
 }
 
-static void check_ascii_to_tcod() {
+static void check_ascii_to_tcod(void) {
 	if ( TCOD_ctx.fontNbCharHoriz * TCOD_ctx.fontNbCharVertic != TCOD_ctx.max_font_chars ) {
 		TCOD_ctx.max_font_chars=TCOD_ctx.fontNbCharHoriz * TCOD_ctx.fontNbCharVertic;
 		alloc_ascii_tables();
@@ -188,7 +180,7 @@ void TCOD_sys_map_ascii_to_font(int asciiCode, int fontCharX, int fontCharY) {
 		TCOD_ctx.ascii_to_tcod[asciiCode] = fontCharX + fontCharY * TCOD_ctx.fontNbCharHoriz;
 }
 
-void TCOD_sys_load_font() {
+void TCOD_sys_load_font(void) {
 	int i;
 	bool hasTransparent=false;
 	int x,y;
@@ -331,11 +323,7 @@ void TCOD_sys_load_font() {
 	rgb_mask=charmap->format->Rmask|charmap->format->Gmask|charmap->format->Bmask;
 	nrgb_mask = ~ rgb_mask;
 	sdl_key &= rgb_mask; /* remove the alpha part */
-#ifdef TCOD_SDL2		
 	if ( charmap->format->BytesPerPixel == 3 ) SDL_SetColorKey(charmap,SDL_TRUE|SDL_RLEACCEL,sdl_key);
-#else
-	if ( charmap->format->BytesPerPixel == 3 ) SDL_SetColorKey(charmap,SDL_SRCCOLORKEY|SDL_RLEACCEL,sdl_key);
-#endif
 	for (i=0; i < TCOD_ctx.fontNbCharHoriz*TCOD_ctx.fontNbCharVertic; i++ ) {
 		charcols[i]=fontKeyCol;
 		first_draw[i]=true;
@@ -384,7 +372,7 @@ void TCOD_sys_set_custom_font(const char *fontFile,int nb_ch, int nb_cv, int fla
 	*/
 }
 
-void find_resolution() {
+void find_resolution(void) {
 	TCOD_ctx.actual_fullscreen_width=TCOD_ctx.fullscreen_width>TCOD_ctx.root->w*TCOD_ctx.font_width?TCOD_ctx.fullscreen_width:TCOD_ctx.root->w*TCOD_ctx.font_width;
 	TCOD_ctx.actual_fullscreen_height=TCOD_ctx.fullscreen_height>TCOD_ctx.root->h*TCOD_ctx.font_height?TCOD_ctx.fullscreen_height:TCOD_ctx.root->h*TCOD_ctx.font_height;
 	sdl->get_closest_mode(&TCOD_ctx.actual_fullscreen_width,&TCOD_ctx.actual_fullscreen_height);
@@ -397,31 +385,43 @@ void *TCOD_sys_create_bitmap_for_console(TCOD_console_t console) {
 	return TCOD_sys_get_surface(w,h,false);
 }
 
-static void TCOD_sys_render(void *vbitmap, int console_width, int console_height, char_t *console_buffer, char_t *prev_console_buffer) {
-	sdl->render(vbitmap,console_width,console_height, console_buffer,prev_console_buffer);
+static void TCOD_sys_render(void *vbitmap, int console_width, int console_height, TCOD_render_state_t *render_state) {
+	sdl->render(vbitmap, console_width, console_height, render_state);
 }
 
-void TCOD_sys_console_to_bitmap(void *vbitmap, int console_width, int console_height, char_t *console_buffer, char_t *prev_console_buffer) {
+void TCOD_sys_console_to_bitmap(void *vbitmap, int console_width, int console_height, TCOD_render_state_t *render_state) {
 	static SDL_Surface *charmap_backup=NULL;
+	SDL_Surface *bitmap = (SDL_Surface *)vbitmap;
 	int x,y;
-	SDL_Surface *bitmap=(SDL_Surface *)vbitmap;
-	Uint32 sdl_back=0,sdl_fore=0;
+	Uint32 sdl_back=0, sdl_fore=0;
 	TCOD_color_t fading_color = TCOD_console_get_fading_color();
 	int fade = (int)TCOD_console_get_fade();
-	bool track_changes=(oldFade == fade && prev_console_buffer);
-   	Uint8 bpp = charmap->format->BytesPerPixel;
-	char_t *c=&console_buffer[0];
-	char_t *oc=&prev_console_buffer[0];
+	bool track_changes = (oldFade == fade && render_state->oldbuf);
+	Uint8 bpp = charmap->format->BytesPerPixel;
+	char_t *c=&render_state->buf[0];
+	char_t *oc;
+	TCOD_color_t *ofg, *obg, *nfg, *nbg;
 	int hdelta;
+	if (render_state->clear_screen) {
+		track_changes = false;
+		render_state->clear_screen = false;
+	}
 	if ( bpp == 4 ) {
 		hdelta=(charmap->pitch - TCOD_ctx.font_width*bpp)/4;
 	} else {
 		hdelta=(charmap->pitch - TCOD_ctx.font_width*bpp);
 	}
+	nfg = TCOD_image_get_colors(render_state->fg_colors);
+	nbg = TCOD_image_get_colors(render_state->bg_colors);
+	if (track_changes) {
+		oc = &render_state->oldbuf[0];
+		ofg = TCOD_image_get_colors(render_state->fg_colors_prev);
+		obg = TCOD_image_get_colors(render_state->bg_colors_prev);
+	}
 	if ( charmap_backup == NULL ) {
 		charmap_backup=(SDL_Surface *)TCOD_sys_get_surface(charmap->w,charmap->h,true);
 		SDL_BlitSurface(charmap,NULL,charmap_backup,NULL);
-	}	
+	}
 #ifdef USE_SDL_LOCKS
 	if ( SDL_MUSTLOCK( bitmap ) && SDL_LockSurface( bitmap ) < 0 ) return;
 #endif
@@ -432,16 +432,16 @@ void TCOD_sys_console_to_bitmap(void *vbitmap, int console_width, int console_he
 			if ( c->cf == -1 ) c->cf = TCOD_ctx.ascii_to_tcod[c->c];
 			if ( track_changes ) {
 				changed=false;
-				if ( c->dirt || ascii_updated[ c->c ] || c->back.r != oc->back.r || c->back.g != oc->back.g
-					|| c->back.b != oc->back.b || c->fore.r != oc->fore.r
-					|| c->fore.g != oc->fore.g || c->fore.b != oc->fore.b
-					|| c->c != oc->c || c->cf != oc->cf) {
+				if (c->dirty || ascii_updated[c->c] ||
+					nbg->r != obg->r || nbg->g != obg->g || nbg->b != obg->b ||
+					nfg->r != ofg->r || nfg->g != ofg->g || nfg->b != ofg->b ||
+					c->c != oc->c || c->cf != oc->cf) {
 					changed=true;
 				}
 			}
-			c->dirt=0;
+			c->dirty=0;
 			if ( changed ) {
-				TCOD_color_t b=c->back;
+				TCOD_color_t b=*nbg;
 				dstRect.x=x*TCOD_ctx.font_width;
 				dstRect.y=y*TCOD_ctx.font_height;
 				dstRect.w=TCOD_ctx.font_width;
@@ -453,20 +453,13 @@ void TCOD_sys_console_to_bitmap(void *vbitmap, int console_width, int console_he
 					b.b = ((int)b.b) * fade / 255 + ((int)fading_color.b) * (255-fade)/255;
 				}
 				sdl_back=SDL_MapRGB(bitmap->format,b.r,b.g,b.b);
-#ifdef TCOD_SDL2
-#else
-				if ( bitmap == screen && TCOD_ctx.fullscreen ) {
-					dstRect.x+=TCOD_ctx.fullscreen_offsetx;
-					dstRect.y+=TCOD_ctx.fullscreen_offsety;
-				}
-#endif
 				SDL_FillRect(bitmap,&dstRect,sdl_back);
 				if ( c->c != ' ' ) {
 					/* draw foreground */
 					int ascii=c->cf;
 					TCOD_color_t *curtext = &charcols[ascii];
 					bool first = first_draw[ascii];
-					TCOD_color_t f=c->fore;
+					TCOD_color_t f=*nfg;
 
 					if ( fade != 255 ) {
 						f.r = ((int)f.r) * fade / 255 + ((int)fading_color.r) * (255-fade)/255;
@@ -589,7 +582,14 @@ void TCOD_sys_console_to_bitmap(void *vbitmap, int console_width, int console_he
 					}
 				}
 			}
-			c++;oc++;
+			c++;
+			nfg++;
+			nbg++;
+			if (track_changes) {
+				oc++;
+				ofg++;
+				obg++;
+			}
 		}
 	}
 #ifdef USE_SDL_LOCKS
@@ -597,12 +597,6 @@ void TCOD_sys_console_to_bitmap(void *vbitmap, int console_width, int console_he
 #endif
 }
 
-void TCOD_sys_set_keyboard_repeat(int initial_delay, int interval) {
-#ifndef TCOD_SDL2
-	SDL_EnableKeyRepeat(initial_delay,interval);
-#endif
-}
-
 void *TCOD_sys_get_surface(int width, int height, bool alpha) {
 	return sdl->create_surface(width,height,alpha);
 }
@@ -641,29 +635,14 @@ void TCOD_sys_update_char(int asciiCode, int fontx, int fonty, TCOD_image_t img,
 	any_ascii_updated=true;
 }
 
-#ifdef TCOD_MACOSX
-void CustomSDLMain();
-#endif
-
-void TCOD_sys_startup() {
+void TCOD_sys_startup(void) {
 	if (has_startup) return;
 	sdl = SDL_implementation_factory();
-#ifdef TCOD_MACOSX
-	CustomSDLMain();
-#endif
-#ifdef TCOD_SDL2
 #ifndef NDEBUG
 	SDL_LogSetAllPriority(SDL_LOG_PRIORITY_VERBOSE);
 #endif
-#endif
-	TCOD_IFNOT(SDL_Init(SDL_INIT_TIMER|SDL_INIT_VIDEO) >= 0 ) return;
-#ifndef	TCOD_WINDOWS
-	/* not needed and might crash on windows */
+	TCOD_IFNOT(SDL_Init(SDL_INIT_VIDEO) >= 0 ) return;
 	atexit(SDL_Quit);
-#endif
-#ifndef TCOD_SDL2
-	SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY,SDL_DEFAULT_REPEAT_INTERVAL);
-#endif
 	memset(&TCOD_ctx.key_state,0,sizeof(TCOD_key_t));
 	TCOD_ctx.max_font_chars=256;
 	alloc_ascii_tables();
@@ -674,7 +653,16 @@ void TCOD_sys_startup() {
 	has_startup=true;
 }
 
-static void TCOD_sys_load_player_config() {
+void TCOD_sys_shutdown(void) {
+	if (!has_startup) return;
+	TCOD_sys_uninit();
+	sdl->shutdown();
+	SDL_Quit();
+	memset(&scale_data, 0, sizeof(scale_data_t));
+	has_startup = false;
+}
+
+static void TCOD_sys_load_player_config(void) {
 	const char *renderer;	
 	const char *font;	
 	int fullscreenWidth,fullscreenHeight;
@@ -736,31 +724,25 @@ static void TCOD_sys_load_player_config() {
 }
 
 
-TCOD_renderer_t TCOD_sys_get_renderer() {
+TCOD_renderer_t TCOD_sys_get_renderer(void) {
 	return TCOD_ctx.renderer;
 }
 
 void TCOD_sys_set_renderer(TCOD_renderer_t renderer) {
 	if ( renderer == TCOD_ctx.renderer ) return;
 	TCOD_ctx.renderer=renderer;
-#ifdef TCOD_SDL2
-	if ( window ) {
-#else
-	if ( screen ) {
-#endif
-		TCOD_sys_term();
-	}
-	TCOD_sys_init(TCOD_ctx.root->w,TCOD_ctx.root->h,TCOD_ctx.root->buf,TCOD_ctx.root->oldbuf,TCOD_ctx.fullscreen);
+	TCOD_sys_uninit();
+	TCOD_sys_init(TCOD_ctx.root->w,TCOD_ctx.root->h,&TCOD_ctx.root->state,TCOD_ctx.fullscreen);
 	TCOD_console_set_window_title(TCOD_ctx.window_title);
 	TCOD_console_set_dirty(0,0,TCOD_ctx.root->w,TCOD_ctx.root->h);
 }
 
-void TCOD_sys_init_screen_offset() {
+void TCOD_sys_init_screen_offset(void) {
 	TCOD_ctx.fullscreen_offsetx=(TCOD_ctx.actual_fullscreen_width-TCOD_ctx.root->w*TCOD_ctx.font_width)/2;
 	TCOD_ctx.fullscreen_offsety=(TCOD_ctx.actual_fullscreen_height-TCOD_ctx.root->h*TCOD_ctx.font_height)/2;
 }
 
-bool TCOD_sys_init(int w,int h, char_t *buf, char_t *oldbuf, bool fullscreen) {
+bool TCOD_sys_init(int w,int h, TCOD_render_state_t *render_state, bool fullscreen) {
 	static TCOD_renderer_t last_renderer=TCOD_RENDERER_SDL;
 	static char last_font[512]="";
 	if ( ! has_startup ) TCOD_sys_startup();
@@ -775,13 +757,18 @@ bool TCOD_sys_init(int w,int h, char_t *buf, char_t *oldbuf, bool fullscreen) {
 		TCOD_sys_load_font();
 	}
 	sdl->create_window(w,h,fullscreen);
-	consoleBuffer=buf;
-	prevConsoleBuffer=oldbuf;
+	renderState = render_state;
 	memset(key_status,0,sizeof(bool)*(TCODK_CHAR+1));
 	memset(ascii_updated,0,sizeof(bool)*TCOD_ctx.max_font_chars);
 	return true;
 }
 
+void TCOD_sys_uninit(void) {
+	if (!has_startup) return;
+	renderState = NULL;
+	sdl->destroy_window();
+}
+
 void TCOD_sys_save_bitmap(void *bitmap, const char *filename) {
 	image_support_t *img=image_type;
 	while ( img->extension != NULL && strcasestr(filename,img->extension) == NULL ) img++;
@@ -813,7 +800,6 @@ void TCOD_sys_set_fullscreen(bool fullscreen) {
 	sdl->set_fullscreen(fullscreen);
 }
 
-#ifdef TCOD_SDL2
 void TCOD_sys_set_scale_factor(float value) {
 	float old_scale_factor = scale_factor;
 	scale_factor = value;
@@ -823,7 +809,6 @@ void TCOD_sys_set_scale_factor(float value) {
 		scale_factor = MAX_SCALE_FACTOR;
 	printf("scale_factor: %0.3f -> %0.3f (wanted: %0.3f)", old_scale_factor, scale_factor, value);
 }
-#endif
 
 void TCOD_sys_set_window_title(const char *title) {
 	strcpy(TCOD_ctx.window_title,title);
@@ -834,11 +819,7 @@ void TCOD_sys_flush(bool render) {
 	static uint32 old_time,new_time=0, elapsed=0;
 	int32 frame_time,time_to_wait;
 	if ( render ) {
-#ifdef TCOD_SDL2	
-		TCOD_sys_render(NULL,TCOD_console_get_width(NULL),TCOD_console_get_height(NULL),consoleBuffer, prevConsoleBuffer);
-#else
-		TCOD_sys_render(screen,TCOD_console_get_width(NULL),TCOD_console_get_height(NULL),consoleBuffer, prevConsoleBuffer);
-#endif
+		TCOD_sys_render(NULL, TCOD_console_get_width(NULL), TCOD_console_get_height(NULL), renderState);
 	}
 	old_time=new_time;
 	new_time=TCOD_sys_elapsed_milli();
@@ -864,7 +845,6 @@ void TCOD_sys_flush(bool render) {
 	last_frame_length = frame_time * 0.001f;
 }
 
-#ifdef TCOD_SDL2	
 static char TCOD_sys_get_vk(SDL_Keycode sdl_key) {
 	int i;
 	for (i = 0; i < NUM_VK_TO_C_ENTRIES; i++) {
@@ -886,11 +866,9 @@ static void TCOD_sys_set_vk(SDL_Keycode sdl_key, char tcod_key) {
 		}
 	}
 }
-#endif
 
 static void TCOD_sys_convert_event(SDL_Event *ev, TCOD_key_t *ret) {
 	SDL_KeyboardEvent *kev=&ev->key;
-#ifdef TCOD_SDL2
 	/* SDL2 does not map keycodes and modifiers to characters, this is on the developer.
 		Presumably in order to avoid problems with different keyboard layouts, they
 		are expected to write their own key mapping editing code for the user.  */
@@ -898,22 +876,14 @@ static void TCOD_sys_convert_event(SDL_Event *ev, TCOD_key_t *ret) {
 		ret->c = 0;
 	else
 		ret->c = kev->keysym.sym;
-#else
-	ret->c=(char)kev->keysym.unicode;
-#endif
 	if ( ( kev->keysym.mod & (KMOD_LCTRL|KMOD_RCTRL) ) != 0 ) {
 		/* when pressing CTRL-A, we don't get unicode for 'a', but unicode for CTRL-A = 1. Fix it */
 		if ( kev->keysym.sym >= SDLK_a && kev->keysym.sym <= SDLK_z ) {
 			ret->c = 'a'+(kev->keysym.sym - SDLK_a);
 		}
 	}
-#ifdef TCOD_SDL2	
 	if ( ev->type == SDL_KEYDOWN ) TCOD_sys_set_vk(kev->keysym.sym, ret->c);
 	else if (ev->type == SDL_KEYUP ) ret->c = TCOD_sys_get_vk(kev->keysym.sym);
-#else
-	if ( ev->type == SDL_KEYDOWN ) vk_to_c[kev->keysym.sym] = ret->c;
-	else if (ev->type == SDL_KEYUP ) ret->c = vk_to_c[kev->keysym.sym];
-#endif
 	switch(kev->keysym.sym) {
 		case SDLK_ESCAPE : ret->vk=TCODK_ESCAPE;break;
 		case SDLK_SPACE : ret->vk=TCODK_SPACE; break;
@@ -930,11 +900,7 @@ static void TCOD_sys_convert_event(SDL_Event *ev, TCOD_key_t *ret) {
 		case SDLK_LALT : case SDLK_RALT : ret->vk=TCODK_ALT;break;
 		case SDLK_LCTRL : case SDLK_RCTRL : ret->vk=TCODK_CONTROL;break;
 		case SDLK_LSHIFT : case SDLK_RSHIFT : ret->vk=TCODK_SHIFT;break;
-#ifdef TCOD_SDL2	
 		case SDLK_PRINTSCREEN : ret->vk=TCODK_PRINTSCREEN;break;
-#else
-		case SDLK_PRINT : ret->vk=TCODK_PRINTSCREEN;break;
-#endif
 		case SDLK_LEFT : ret->vk=TCODK_LEFT;break;
 		case SDLK_UP : ret->vk=TCODK_UP;break;
 		case SDLK_RIGHT : ret->vk=TCODK_RIGHT;break;
@@ -961,7 +927,6 @@ static void TCOD_sys_convert_event(SDL_Event *ev, TCOD_key_t *ret) {
 		case SDLK_7 : ret->vk=TCODK_7;break;
 		case SDLK_8 : ret->vk=TCODK_8;break;
 		case SDLK_9 : ret->vk=TCODK_9;break;
-#ifdef TCOD_SDL2	
 		case SDLK_RGUI : ret->vk=TCODK_RWIN;break;
 		case SDLK_LGUI : ret->vk=TCODK_LWIN;break;
 		case SDLK_NUMLOCKCLEAR : ret->vk=TCODK_NUMLOCK;break;
@@ -975,20 +940,6 @@ static void TCOD_sys_convert_event(SDL_Event *ev, TCOD_key_t *ret) {
 		case SDLK_KP_7 : ret->vk=TCODK_KP7;break;
 		case SDLK_KP_8 : ret->vk=TCODK_KP8;break;
 		case SDLK_KP_9 : ret->vk=TCODK_KP9;break;
-#else
-		case SDLK_RSUPER : ret->vk=TCODK_RWIN;break;
-		case SDLK_LSUPER : ret->vk=TCODK_LWIN;break;
-		case SDLK_KP0 : ret->vk=TCODK_KP0;break;
-		case SDLK_KP1 : ret->vk=TCODK_KP1;break;
-		case SDLK_KP2 : ret->vk=TCODK_KP2;break;
-		case SDLK_KP3 : ret->vk=TCODK_KP3;break;
-		case SDLK_KP4 : ret->vk=TCODK_KP4;break;
-		case SDLK_KP5 : ret->vk=TCODK_KP5;break;
-		case SDLK_KP6 : ret->vk=TCODK_KP6;break;
-		case SDLK_KP7 : ret->vk=TCODK_KP7;break;
-		case SDLK_KP8 : ret->vk=TCODK_KP8;break;
-		case SDLK_KP9 : ret->vk=TCODK_KP9;break;
-#endif
 		case SDLK_KP_DIVIDE : ret->vk=TCODK_KPDIV;break;
 		case SDLK_KP_MULTIPLY : ret->vk=TCODK_KPMUL;break;
 		case SDLK_KP_PLUS : ret->vk=TCODK_KPADD;break;
@@ -1024,13 +975,8 @@ static TCOD_key_t TCOD_sys_SDLtoTCOD(SDL_Event *ev, int flags) {
 				case SDLK_RCTRL : ret->rctrl=0; break;
 				case SDLK_LSHIFT : ret->shift=0; break;
 				case SDLK_RSHIFT : ret->shift=0; break;
-#ifdef TCOD_SDL2
 				case SDLK_LGUI : ret->lmeta=0; break;
 				case SDLK_RGUI : ret->rmeta=0; break;
-#else
-				case SDLK_LSUPER : ret->lmeta=0; break;
-				case SDLK_RSUPER : ret->rmeta=0; break;
-#endif
 				default:break;
 			}
 			TCOD_sys_convert_event(ev,&tmpkey);
@@ -1052,13 +998,8 @@ static TCOD_key_t TCOD_sys_SDLtoTCOD(SDL_Event *ev, int flags) {
 				case SDLK_RCTRL : ret->rctrl=1; break;
 				case SDLK_LSHIFT : ret->shift=1; break;
 				case SDLK_RSHIFT : ret->shift=1; break;
-#ifdef TCOD_SDL2
 				case SDLK_LGUI : ret->lmeta=1; break;
 				case SDLK_RGUI : ret->rmeta=1; break;
-#else
-				case SDLK_LSUPER : ret->lmeta=1; break;
-				case SDLK_RSUPER : ret->rmeta=1; break;
-#endif
 				default : break;
 			}
 			TCOD_sys_convert_event(ev,&tmpkey);
@@ -1120,6 +1061,7 @@ void TCOD_sys_convert_screen_to_console_coords(int sx, int sy, int *cx, int *cy)
 static TCOD_mouse_t tcod_mouse={0,0,0,0,0,0,0,0,false,false,false,false,false,false,false,false};
 static TCOD_event_t TCOD_sys_handle_event(SDL_Event *ev,TCOD_event_t eventMask, TCOD_key_t *key, TCOD_mouse_t *mouse) {
 	TCOD_event_t retMask=0;
+	key->text[0] = '\0';
 	/* printf("TCOD_sys_handle_event type=%04x\n", ev->type); */
 	switch(ev->type) {
 		case SDL_KEYDOWN : {		 
@@ -1140,7 +1082,6 @@ static TCOD_event_t TCOD_sys_handle_event(SDL_Event *ev,TCOD_event_t eventMask,
 			}
 		}
 		break;
-#ifdef TCOD_SDL2
 		case SDL_TEXTINPUT: {
 			SDL_TextInputEvent *iev=&ev->text;
 			TCOD_key_t ret;
@@ -1151,14 +1092,6 @@ static TCOD_event_t TCOD_sys_handle_event(SDL_Event *ev,TCOD_event_t eventMask,
 			return retMask | TCOD_EVENT_KEY_PRESS; 
 		}
 		break;
-#else
-		case SDL_ACTIVEEVENT : 
-			switch(ev->active.state) {
-				case SDL_APPMOUSEFOCUS : TCOD_ctx.app_has_mouse_focus=ev->active.gain; break;
-				default : TCOD_ctx.app_is_active=ev->active.gain; break;
-			}
-		break;
-#endif
 #ifdef TCOD_TOUCH_INPUT
 		/*
 		 * Need to distinguish between:
@@ -1337,7 +1270,6 @@ static TCOD_event_t TCOD_sys_handle_event(SDL_Event *ev,TCOD_event_t eventMask,
 				return retMask | TCOD_EVENT_MOUSE_MOVE;
 			}
 		break; 
-#ifdef TCOD_SDL2
 		case SDL_MOUSEWHEEL :
 			if (ev->wheel.y < 0)
 				mouse->wheel_down=true;
@@ -1345,7 +1277,6 @@ static TCOD_event_t TCOD_sys_handle_event(SDL_Event *ev,TCOD_event_t eventMask,
 				mouse->wheel_up=true;
 			return retMask | TCOD_EVENT_MOUSE_PRESS;
 		break;
-#endif
 		case SDL_MOUSEBUTTONDOWN : 
 			if ( (TCOD_EVENT_MOUSE_PRESS & eventMask) != 0) {
 				SDL_MouseButtonEvent *mev=&ev->button;
@@ -1354,10 +1285,6 @@ static TCOD_event_t TCOD_sys_handle_event(SDL_Event *ev,TCOD_event_t eventMask,
 					case SDL_BUTTON_LEFT : mouse->lbutton=mousebl=true; break;
 					case SDL_BUTTON_MIDDLE : mouse->mbutton=mousebm=true; break;
 					case SDL_BUTTON_RIGHT : mouse->rbutton=mousebr=true; break;
-#ifndef TCOD_SDL2
-					case SDL_BUTTON_WHEELUP : mouse->wheel_up=true; break;
-					case SDL_BUTTON_WHEELDOWN : mouse->wheel_down=true;break;
-#endif
 				}
 				/* update mouse position */
 				if ( (TCOD_EVENT_MOUSE_MOVE & eventMask) == 0) {
@@ -1391,7 +1318,6 @@ static TCOD_event_t TCOD_sys_handle_event(SDL_Event *ev,TCOD_event_t eventMask,
 		case SDL_QUIT :
 			TCOD_ctx.is_window_closed=true;
 		break;
-#ifdef TCOD_SDL2
 		case SDL_WINDOWEVENT :
 			/* At this point, there are some corner cases that need dealing with.  So log this. */
 			/* printf("SDL2 WINDOWEVENT: 0x%04x\n", ev->window.event); */
@@ -1415,7 +1341,7 @@ static TCOD_event_t TCOD_sys_handle_event(SDL_Event *ev,TCOD_event_t eventMask,
 			case SDL_WINDOWEVENT_MINIMIZED:      /**< Window has been minimized */
 				TCOD_ctx.app_is_active=false; break;
 			case SDL_WINDOWEVENT_EXPOSED:        /**< Window has been returned to and needs a refresh. */
-				TCOD_sys_render(NULL,TCOD_console_get_width(NULL),TCOD_console_get_height(NULL),consoleBuffer, prevConsoleBuffer);
+				TCOD_sys_render(NULL,TCOD_console_get_width(NULL),TCOD_console_get_height(NULL), renderState);
 				break;
 #ifdef NDEBUG_HMM
 			default:
@@ -1424,11 +1350,6 @@ static TCOD_event_t TCOD_sys_handle_event(SDL_Event *ev,TCOD_event_t eventMask,
 #endif
 			}
  		break;
-#else
-		case SDL_VIDEOEXPOSE :
-			TCOD_sys_console_to_bitmap(screen,TCOD_console_get_width(NULL),TCOD_console_get_height(NULL),consoleBuffer,prevConsoleBuffer);
-		break;			
-#endif
 		default : break; 
 	}
 	return retMask;
@@ -1487,7 +1408,7 @@ TCOD_event_t TCOD_sys_check_for_event(int eventMask, TCOD_key_t *key, TCOD_mouse
 	return retMask;
 }
 
-TCOD_mouse_t TCOD_mouse_get_status() {
+TCOD_mouse_t TCOD_mouse_get_status(void) {
 	return tcod_mouse;
 }
 
@@ -1521,13 +1442,6 @@ void TCOD_sys_sleep_milli(uint32 milliseconds) {
 	SDL_Delay(milliseconds);
 }
 
-void TCOD_sys_term() {
-	sdl->term();
-	SDL_Quit();
-	memset(&scale_data,0,sizeof(scale_data_t));
-	has_startup=false;
-}
-
 void *TCOD_sys_load_image(const char *filename) {
 	image_support_t *img=image_type;
 	while ( img->extension != NULL && !img->check_type(filename) ) img++;
@@ -1581,11 +1495,11 @@ int TCOD_sys_get_image_alpha(const void *image,int x, int y) {
 	return *((bits)+surf->format->Ashift/8);
 }
 
-uint32 TCOD_sys_elapsed_milli() {
+uint32 TCOD_sys_elapsed_milli(void) {
 	return (uint32)SDL_GetTicks();
 }
 
-float TCOD_sys_elapsed_seconds() {
+float TCOD_sys_elapsed_seconds(void) {
 	static float div=1.0f/1000.0f;
 	return SDL_GetTicks()*div;
 }
@@ -1595,25 +1509,6 @@ void TCOD_sys_force_fullscreen_resolution(int width, int height) {
 	TCOD_ctx.fullscreen_height=height;
 }
 
-/*
-void * TCOD_sys_create_bitmap(int width, int height, TCOD_color_t *buf) {
-	int x,y;
-	SDL_Surface *bitmap=SDL_CreateRGBSurface(SDL_SWSURFACE,width,height,charmap->format->BitsPerPixel,
-		charmap->format->Rmask,charmap->format->Gmask,charmap->format->Bmask,charmap->format->Amask);
-	for (x=0; x < width; x++) {
-		for (y=0; y < height; y++) {
-			SDL_Rect rect;
-			Uint32 col=SDL_MapRGB(charmap->format,buf[x+y*width].r,buf[x+y*width].g,buf[x+y*width].b);
-			rect.x=x;
-			rect.y=y;
-			rect.w=1;
-			rect.h=1;
-			SDL_FillRect(bitmap,&rect,col);
-		}
-	}
-	return (void *)bitmap;
-}
-*/
 void * TCOD_sys_create_bitmap(int width, int height, TCOD_color_t *buf) {
 	int x,y;
 	SDL_PixelFormat fmt;
@@ -1658,19 +1553,19 @@ void TCOD_sys_set_fps(int val) {
 	else min_frame_length=1000/val;
 }
 
-void TCOD_sys_save_fps() {
+void TCOD_sys_save_fps(void) {
 	min_frame_length_backup=min_frame_length;
 }
 
-void TCOD_sys_restore_fps() {
+void TCOD_sys_restore_fps(void) {
 	min_frame_length=min_frame_length_backup;
 }
 
-int TCOD_sys_get_fps() {
+int TCOD_sys_get_fps(void) {
 	return fps;
 }
 
-float TCOD_sys_get_last_frame_length() {
+float TCOD_sys_get_last_frame_length(void) {
 	return last_frame_length;
 }
 
@@ -1689,7 +1584,6 @@ void TCOD_sys_get_current_resolution(int *w, int *h) {
 bool TCOD_sys_check_magic_number(const char *filename, int size, uint8 *data) {
 	uint8 tmp[128];
 	int i;
-#ifdef TCOD_SDL2
 	SDL_RWops *rwops =  SDL_RWFromFile(filename, "rb");
 	if (! rwops) return false;
 	if ( (i = rwops->read(rwops,tmp,size,1)) != 1 ) {
@@ -1697,35 +1591,24 @@ bool TCOD_sys_check_magic_number(const char *filename, int size, uint8 *data) {
 		return false;
 	}
 	rwops->close(rwops);
-#else
-	FILE *f=fopen(filename,"rb");
-	if (! f) return false;
-	if ( fread(tmp,1,128,f) < (unsigned)size ) {
-		fclose(f);
-		return false;
-	}
-	fclose(f);
-#endif
 	for (i=0; i< size; i++) if (tmp[i]!=data[i]) return false;
 	return true;
 }
 
-#ifdef TCOD_SDL2
-void *TCOD_sys_get_SDL_window() {
+void *TCOD_sys_get_SDL_window(void) {
 	return (void *)window;
 }
 
-void *TCOD_sys_get_SDL_renderer() {
+void *TCOD_sys_get_SDL_renderer(void) {
 	return (void *)renderer;
 }
-#endif
 
 /* mouse stuff */
 void TCOD_mouse_show_cursor(bool visible) {
   SDL_ShowCursor(visible ? 1 : 0);
 }
 
-bool TCOD_mouse_is_cursor_visible() {
+bool TCOD_mouse_is_cursor_visible(void) {
   return SDL_ShowCursor(-1) ? true : false;
 }
 
@@ -1739,6 +1622,19 @@ void TCOD_mouse_includes_touch(bool enable) {
 #endif
 }
 
+/*clipboard stuff */
+bool TCOD_sys_clipboard_set(const char *value) {
+	if (!has_startup)
+		return false;
+	return sdl->set_clipboard_text(value);
+}
+
+char *TCOD_sys_clipboard_get() {
+	if (!has_startup)
+		return "";
+	return sdl->get_clipboard_text();
+}
+
 bool TCOD_sys_read_file(const char *filename, unsigned char **buf, size_t *size) {
 	return sdl->file_read(filename,buf,size);
 }
